##############################################################################
# 
# Zope Public License (ZPL) Version 1.0
# -------------------------------------
# 
# Copyright (c) Digital Creations.  All rights reserved.
# 
# This license has been certified as Open Source(tm).
# 
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:
# 
# 1. Redistributions in source code must retain the above copyright
#    notice, this list of conditions, and the following disclaimer.
# 
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions, and the following disclaimer in
#    the documentation and/or other materials provided with the
#    distribution.
# 
# 3. Digital Creations requests that attribution be given to Zope
#    in any manner possible. Zope includes a "Powered by Zope"
#    button that is installed by default. While it is not a license
#    violation to remove this button, it is requested that the
#    attribution remain. A significant investment has been put
#    into Zope, and this effort will continue if the Zope community
#    continues to grow. This is one way to assure that growth.
# 
# 4. All advertising materials and documentation mentioning
#    features derived from or use of this software must display
#    the following acknowledgement:
# 
#      "This product includes software developed by Digital Creations
#      for use in the Z Object Publishing Environment
#      (http://www.zope.org/)."
# 
#    In the event that the product being advertised includes an
#    intact Zope distribution (with copyright and license included)
#    then this clause is waived.
# 
# 5. Names associated with Zope or Digital Creations must not be used to
#    endorse or promote products derived from this software without
#    prior written permission from Digital Creations.
# 
# 6. Modified redistributions of any form whatsoever must retain
#    the following acknowledgment:
# 
#      "This product includes software developed by Digital Creations
#      for use in the Z Object Publishing Environment
#      (http://www.zope.org/)."
# 
#    Intact (re-)distributions of any official Zope release do not
#    require an external acknowledgement.
# 
# 7. Modifications are encouraged but must be packaged separately as
#    patches to official Zope releases.  Distributions that do not
#    clearly separate the patches from the original work must be clearly
#    labeled as unofficial distributions.  Modifications which do not
#    carry the name Zope may be packaged in any form, as long as they
#    conform to all of the clauses above.
# 
# 
# Disclaimer
# 
#   THIS SOFTWARE IS PROVIDED BY DIGITAL CREATIONS ``AS IS'' AND ANY
#   EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
#   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
#   PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL DIGITAL CREATIONS OR ITS
#   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
#   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
#   LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
#   USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
#   ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
#   OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
#   OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
#   SUCH DAMAGE.
# 
# 
# This software consists of contributions made by Digital Creations and
# many individuals on behalf of Digital Creations.  Specific
# attributions are listed in the accompanying credits file.
# 
##############################################################################

"""Navigable Folder object
Folder that helps navigate in websites.
"""

__version__ = '$Revision: 1.2 $'[11:-2]

import Globals, OFS, AccessControl
from Globals import DTMLFile
from OFS import Folder
from AccessControl import getSecurityManager


manage_addNavigableFolderForm = DTMLFile( 'dtml/navigableFolderAdd', globals() )

def manage_addNavigableFolder( self, id, title='', desc='', createPublic=0, createUserF=0, REQUEST=None ):
    """Add a new Navigable Folder object with id *id*.
    """
    ob = NavigableFolder()
    ob.id = str(id)
    ob.title = title
    ob.description = desc
    ob.order = len( self.objectItems( 'Navigable Folder' ) )
    
    self._setObject( id, ob )
    ob = self._getOb( id )

    checkPermission=getSecurityManager().checkPermission

    # Create user folder if wanted
    if createUserF:
       if not checkPermission('Add User Folders', ob):
          raise 'Unauthorized', ( 'You are not authorized to add User Folders.' )
       ob.manage_addUserFolder()

    # Add default index_html
    if createPublic:
       if not checkPermission( 'Add Documents, Images, and Files', ob ):
	  raise 'Unauthorized', ( 'You are not authorized to add DTML Documents.' )
       ob.manage_addDTMLDocument( 'index_html', title, DTMLFile( 'dtml/default_index', globals() ) )

    # Redirect if it's possible
    if REQUEST is not None:
        return self.manage_main( self, REQUEST )



class NavigableFolder( Folder.Folder ):
    """Base Class for NavigableFolder Product
    """
    meta_type = 'Navigable Folder'

    _properties = (
         { 'id' : 'title', 'type' : 'string' },
         { 'id' : 'description', 'type' : 'text' }, 
	 { 'id' : 'order', 'type' : 'int' },
    )

    def father_folders( self ):
       """
       Return a map of ( parent title_or_id, parent url ).
       """
       self.objectIds()
       parents = []
       ob = self
       while hasattr( ob, 'aq_parent' ):
	  parents = [ob] + parents
	  ob = ob.aq_parent
       return map( lambda i : ( i.title_or_id(), i.absolute_url() ), parents )



